==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/it.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Loading accounts" : "Caricamento account",
    "Error while loading the accounts." : "Errore durante il caricamento degli account.",
    "Error while loading the selected account." : "Errore durante il caricamento dell'account selezionato.",
    "Can not load this folder." : "Impossibile caricare questa cartella.",
    "Searching for {query}" : "Ricerca di {query}",
    "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
    "Forwarded message" : "Messaggio inoltrato",
    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
    "Attachments saved to Files." : "Allegati salvati in File.",
    "Attachment saved to Files." : "Allegato salvato in File.",
    "Error while saving attachments to Files." : "Errore durante il salvataggio degli allegati in File.",
    "Error while saving attachment to Files." : "Errore durante il salvataggio dell'allegato in File.",
    "Message flag could not be set." : "Il contrassegno del messaggio non può essere impostato.",
    "Could not move message." : "Impossibile spostare il messaggio.",
    "Invalid account" : "Account non valido",
    "Invalid folder" : "Cartella non valida",
    "Error while creating the account: " : "Errore durante la creazione dell'account:",
    "Unknown error" : "Errore sconosciuto",
    "Error while updating the account: " : "Errore durante l'aggiornamento dell'account:",
    "All inboxes" : "Tutte le caselle di posta",
    "you" : "tu",
    "Send message to {email}" : "Invia messaggio a {email}",
    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
    "Could not load your message" : "Impossibile caricare il tuo messaggio",
    "Could not load the desired message" : "Impossibile caricare messaggio desiderato",
    "Could not load the message" : "Impossibile caricare il messaggio",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Salva",
    "Saved" : "Salvato",
    "Show all folders" : "Mostra tutte le cartelle",
    "Collapse folders" : "Contrai le cartelle",
    "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "An error occurred while uploading {fname}" : "Si è verificato un errore durante il caricamento di {fname}",
    "Reply" : "Rispondi",
    "Send" : "Invia",
    "Sending …" : "Invio in corso...",
    "Message sent!" : "Messaggio inviato!",
    "Server error" : "Errore del server",
    "An unknown error occurred" : "Si è verificato un errore sconosciuto",
    "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
    "No writable calendars found" : "Nessun calendario scrivibile trovato",
    "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
    "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
    "& others" : "e altri",
    "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
    "Error while refreshing messages." : "Errore durante l'aggiornamento dei messaggi.",
    "Setting up your account" : "Configurazione del tuo account",
    "Inbox" : "Posta in arrivo",
    "Sent" : "Posta inviata",
    "Drafts" : "Bozze",
    "Archive" : "Archivio",
    "Trash" : "Cestino",
    "Junk" : "Posta indesiderata",
    "All" : "Tutti",
    "Favorites" : "Preferiti",
    "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
    "Updating account failed: " : "Aggiornamento account non riuscito:",
    "Creating account failed: " : "Creazione account non riuscita:",
    "Delete permanently" : "Elimina definitivamente",
    "Error loading message" : "Errore durante il caricamento del messaggio",
    "Settings" : "Impostazioni",
    "Forwarding to %s" : "Inoltro a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
    "Redirect" : "Redirigi",
    "The link leads to %s" : "Il collegamento conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
    "Continue to %s" : "Continua su %s",
    "Delete account" : "Elimina account",
    "Try again" : "Riprova",
    "New message" : "Nuovo messaggio",
    "Account Settings" : "Impostazioni account",
    "Aliases" : "Alias",
    "Mail address" : "Indirizzo di posta",
    "Display Name" : "Nome visualizzato",
    "Account" : "Account",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
    "Compose new message" : "Componi nuovo messaggio",
    "Newer message" : "Messaggio più recente",
    "Older message" : "Messaggio più datato",
    "Toggle star" : "Commuta stella",
    "Toggle unread" : "Commuta non letto",
    "Delete" : "Elimina",
    "Search" : "Cerca",
    "Refresh" : "Aggiorna",
    "Connect your mail account" : "Connetti il tuo account di posta",
    "Name" : "Nome",
    "Mail Address" : "Indirizzo di posta",
    "Password" : "Password",
    "Manual configuration" : "Configurazione manuale",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Sicurezza IMAP",
    "None" : "Nessuna",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Utente IMAP",
    "IMAP Password" : "Password IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Sicurezza SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Connect" : "Connetti",
    "from" : "da",
    "to" : "a",
    "cc" : "cc",
    "bcc" : "ccn",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
    "Subject" : "Oggetto",
    "Save all to Files" : "Salva tutto in File",
    "Add mail account" : "Aggiungi account di posta",
    "Use Gravatar and favicon avatars" : "Utilizzare Gravatar e avatar favicon",
    "No search results for" : "Nessun risultato di ricerca per",
    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
    "Show images from this sender" : "Mostra immagini da questo mittente",
    "Forward" : "Inoltra",
    "No messages in this folder!" : "Nessun messaggio in questa cartella",
    "Upload attachment" : "Carica allegato",
    "Add attachment from Files" : "Aggiungi allegato da File",
    "Import into calendar" : "Importa nel calendario",
    "Download attachment" : "Scarica allegato",
    "Save to Files" : "Salva in File"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/it.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Loading accounts" : "Caricamento account",
    "Error while loading the accounts." : "Errore durante il caricamento degli account.",
    "Can not load this folder." : "Impossibile caricare questa cartella.",
    "Searching for {query}" : "Ricerca di {query}",
    "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
    "Forwarded message" : "Messaggio inoltrato",
    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
    "Attachments saved to Files." : "Allegati salvati in File.",
    "Attachment saved to Files." : "Allegato salvato in File.",
    "Error while saving attachments to Files." : "Errore durante il salvataggio degli allegati in File.",
    "Error while saving attachment to Files." : "Errore durante il salvataggio dell'allegato in File.",
    "Message flag could not be set." : "Il contrassegno del messaggio non può essere impostato.",
    "Could not move message." : "Impossibile spostare il messaggio.",
    "Invalid account" : "Account non valido",
    "Invalid folder" : "Cartella non valida",
    "Error while creating the account: " : "Errore durante la creazione dell'account:",
    "Unknown error" : "Errore sconosciuto",
    "Error while updating the account: " : "Errore durante l'aggiornamento dell'account:",
    "All inboxes" : "Tutte le caselle di posta",
    "you" : "tu",
    "Send message to {email}" : "Invia messaggio a {email}",
    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
    "Could not load your message" : "Impossibile caricare il tuo messaggio",
    "Could not load the desired message" : "Impossibile caricare messaggio desiderato",
    "Could not load the message" : "Impossibile caricare il messaggio",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Salva",
    "Saved" : "Salvato",
    "Show all folders" : "Mostra tutte le cartelle",
    "Collapse folders" : "Contrai le cartelle",
    "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "An error occurred while uploading {fname}" : "Si è verificato un errore durante il caricamento di {fname}",
    "Reply" : "Rispondi",
    "Send" : "Invia",
    "Sending …" : "Invio in corso...",
    "Message sent!" : "Messaggio inviato!",
    "Server error" : "Errore del server",
    "An unknown error occurred" : "Si è verificato un errore sconosciuto",
    "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
    "No writable calendars found" : "Nessun calendario scrivibile trovato",
    "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
    "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
    "& others" : "e altri",
    "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
    "Error while refreshing messages." : "Errore durante l'aggiornamento dei messaggi.",
    "Setting up your account" : "Configurazione del tuo account",
    "Inbox" : "Posta in arrivo",
    "Sent" : "Posta inviata",
    "Drafts" : "Bozze",
    "Archive" : "Archivio",
    "Trash" : "Cestino",
    "Junk" : "Posta indesiderata",
    "All" : "Tutti",
    "Favorites" : "Preferiti",
    "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
    "Updating account failed: " : "Aggiornamento account non riuscito:",
    "Creating account failed: " : "Creazione account non riuscita:",
    "Delete permanently" : "Elimina definitivamente",
    "Error loading message" : "Errore durante il caricamento del messaggio",
    "Settings" : "Impostazioni",
    "Forwarding to %s" : "Inoltro a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
    "Redirect" : "Redirigi",
    "The link leads to %s" : "Il collegamento conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
    "Continue to %s" : "Continua su %s",
    "Delete account" : "Elimina account",
    "Try again" : "Riprova",
    "New message" : "Nuovo messaggio",
    "Account Settings" : "Impostazioni account",
    "Aliases" : "Alias",
    "Mail address" : "Indirizzo di posta",
    "Display Name" : "Nome visualizzato",
    "Account" : "Account",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
    "Compose new message" : "Componi nuovo messaggio",
    "Newer message" : "Messaggio più recente",
    "Older message" : "Messaggio più datato",
    "Toggle star" : "Commuta stella",
    "Toggle unread" : "Commuta non letto",
    "Delete" : "Elimina",
    "Search" : "Cerca",
    "Refresh" : "Aggiorna",
    "Connect your mail account" : "Connetti il tuo account di posta",
    "Name" : "Nome",
    "Mail Address" : "Indirizzo di posta",
    "Password" : "Password",
    "Manual configuration" : "Configurazione manuale",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Sicurezza IMAP",
    "None" : "Nessuna",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Utente IMAP",
    "IMAP Password" : "Password IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Sicurezza SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Connect" : "Connetti",
    "from" : "da",
    "to" : "a",
    "cc" : "cc",
    "bcc" : "ccn",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
    "Subject" : "Oggetto",
    "Save all to Files" : "Salva tutto in File",
    "Add mail account" : "Aggiungi account di posta",
    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
    "No search results for" : "Nessun risultato di ricerca per",
    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
    "Show images from this sender" : "Mostra immagini da questo mittente",
    "Forward" : "Inoltra",
    "No messages in this folder" : "Nessun messaggio in questa cartella",
    "Upload attachment" : "Carica allegato",
    "Add attachment from Files" : "Aggiungi allegato da File",
    "Import into calendar" : "Importa nel calendario",
    "Download attachment" : "Scarica allegato",
    "Save to Files" : "Salva in File"
},
"nplurals=2; plural=(n != 1);");
